import QtQuick 2.0
import Sailfish.Silica 1.0

MouseArea {
    id: closeIcon
    width: Theme.iconSizeMedium
    height: Theme.iconSizeMedium

    property int verticalOffset
    property int horizontalOffset
    property bool inverted
    property real _scale
    Behavior on verticalOffset {
        NumberAnimation { duration: 200 }
    }
    
    Behavior on horizontalOffset {
        NumberAnimation { duration: 200 }
    }
    
    Behavior on opacity {
        NumberAnimation { duration: 200 }
    }

    Rectangle {
        color: inverted ? Theme.secondaryHighlightColor : Theme.primaryColor
        width: Theme.iconSizeMedium
        height: width
        radius: width/2
        anchors.fill: parent
        opacity: 1.0
        scale: _scale
        Image {
            anchors.centerIn: parent
            source: "image://theme/icon-close-app?" + (inverted ? Theme.primaryColor : Theme.highlightBackgroundColor)
        }
    }

    states: [
        State {
            name: ""
            extend: "topRight"
        },
        State {
            name: "topRight"
            AnchorChanges {
                target: closeIcon
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.left: undefined
                anchors.bottom: undefined
                anchors.verticalCenter: undefined
                anchors.horizontalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.topMargin: -closeIcon.verticalOffset
                anchors.rightMargin: -closeIcon.horizontalOffset
            }
        },
        State {
            name: "topLeft"
            AnchorChanges {
                target: closeIcon
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: undefined
                anchors.bottom: undefined
                anchors.verticalCenter: undefined
                anchors.horizontalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.topMargin: -closeIcon.verticalOffset
                anchors.leftMargin: closeIcon.horizontalOffset
            }
        },
        State {
            name: "bottomRight"
            AnchorChanges {
                target: closeIcon
                anchors.bottom: parent.bottom
                anchors.right: parent.right
                anchors.left: undefined
                anchors.top: undefined
                anchors.verticalCenter: undefined
                anchors.horizontalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.bottomMargin: closeIcon.verticalOffset
                anchors.rightMargin: -closeIcon.horizontalOffset
            }
        },
        State {
            name: "bottomLeft"
            AnchorChanges {
                target: closeIcon
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                anchors.right: undefined
                anchors.top: undefined
                anchors.verticalCenter: undefined
                anchors.horizontalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.bottomMargin: closeIcon.verticalOffset
                anchors.leftMargin: closeIcon.horizontalOffset
            }
        },
        State {
            name: "top"
            AnchorChanges {
                target: closeIcon
                anchors.top: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.left: undefined
                anchors.right: undefined
                anchors.bottom: undefined
                anchors.verticalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.horizontalCenterOffset: closeIcon.horizontalOffset
                anchors.topMargin: -closeIcon.verticalOffset
            }
        },
        State {
            name: "bottom"
            AnchorChanges {
                target: closeIcon
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.left: undefined
                anchors.right: undefined
                anchors.top: undefined
                anchors.verticalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.horizontalCenterOffset: closeIcon.horizontalOffset
                anchors.bottomMargin: closeIcon.verticalOffset
            }
        },
        State {
            name: "left"
            AnchorChanges {
                target: closeIcon
                anchors.left: parent.left
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: undefined
                anchors.bottom: undefined
                anchors.top: undefined
                anchors.horizontalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.verticalCenterOffset: -closeIcon.verticalOffset
                anchors.leftMargin: closeIcon.horizontalOffset
            }
        },
        State {
            name: "right"
            AnchorChanges {
                target: closeIcon
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: undefined
                anchors.bottom: undefined
                anchors.top: undefined
                anchors.horizontalCenter: undefined
            }
            PropertyChanges {
                target: closeIcon
                anchors.verticalCenterOffset: -closeIcon.verticalOffset
                anchors.rightMargin: -closeIcon.horizontalOffset
            }
        }
    ]
}